Test coverage report: myapp.views

# myapp.views: 3 total statements, 100.0% covered

Generated: Thu 2012-06-07 23:06 SGT

Source file: /Users/martin/Projects/pycon-apac-2012/tdd-with-django/reusable-app/myapp/views.py

Stats: 2 executed, 0 missed, 1 excluded, 3 ignored

1. `"""Views for appname application."""`
2. `from django.views.generic import TemplateView`
3. ``
4. ``
5. `class HomeView(TemplateView):`
6. `template_name = 'myapp/home.html'`